Properties Methods Events Config Options Direct Link

    Filter
      NumericFilter

# Class Ext.ux.grid.filter.NumericFilter

Package: | Ext.ux.grid.filter
Defined In: | NumericFilter.js
Class: | NumericFilter
Extends: | Filter

Filters using an Ext.ux.menu.RangeMenu.

Example Usage:

    var filters = new Ext.ux.grid.GridFilters({
        ...
        filters: [{
            type: 'numeric',
            dataIndex: 'price'
        }]
    });

## Config Options

Config Options | Defined By
--- | ---
| active : Boolean Indicates the initial status of the filter (defaults to false). | Filter
| dataIndex : String The Ext.data.Store dataIndex of the field this filter represents. The dataIndex does not actually have to exist in th... The Ext.data.Store dataIndex of the field this filter represents. The dataIndex does not actually have to exist in the store. | Filter
| fieldCfg : Object The default configuration options for any field item unless superseded by the fields configuration. Defaults to: fiel... The default configuration options for any field item unless superseded by the `fields` configuration. Defaults to:
    fieldCfg : {}
Example usage:
    fieldCfg : {
        width: 150,
    },
| NumericFilter
| fieldCfg : Object The default configuration options for any field item unless superseded by the fields configuration. Defaults to: fiel... The default configuration options for any field item unless superseded by the `fields` configuration. Defaults to:
    fieldCfg : {}
Example usage:
    fieldCfg : {
        width: 150,
    },
| NumericFilter
| fieldCls : Object The Class to use to construct each field item within this menu Defaults to:
    fieldCls : Ext.form.NumberField
| NumericFilter
| fieldCls : Object The Class to use to construct each field item within this menu Defaults to:
    fieldCls : Ext.form.NumberField
| NumericFilter
| fields : Object The field items may be configured individually Defaults to undefined. Example usage: fields : { gt: { // override... The field items may be configured individually Defaults to `undefined`. Example usage:
    fields : {
        gt: { // override fieldCfg options
            width: 200,
            fieldCls: Ext.ux.form.CustomNumberField // to override default fieldCls
        }
    },
| NumericFilter
| fields : Object The field items may be configured individually Defaults to undefined. Example usage: fields : { gt: { // override... The field items may be configured individually Defaults to `undefined`. Example usage:
    fields : {
        gt: { // override fieldCfg options
            width: 200,
            fieldCls: Ext.ux.form.CustomNumberField // to override default fieldCls
        }
    },
| NumericFilter
| iconCls : Object The iconCls to be applied to each comparator field item. Defaults to: iconCls : { gt : 'ux-rangemenu-gt', lt ... The iconCls to be applied to each comparator field item. Defaults to:
    iconCls : {
        gt : 'ux-rangemenu-gt',
        lt : 'ux-rangemenu-lt',
        eq : 'ux-rangemenu-eq'
    }
| NumericFilter
| iconCls : Object The iconCls to be applied to each comparator field item. Defaults to: iconCls : { gt : 'ux-rangemenu-gt', lt ... The iconCls to be applied to each comparator field item. Defaults to:
    iconCls : {
        gt : 'ux-rangemenu-gt',
        lt : 'ux-rangemenu-lt',
        eq : 'ux-rangemenu-eq'
    }
| NumericFilter
| menuItemCfgs : Object Default configuration options for each menu item Defaults to: menuItemCfgs : { emptyText: 'Enter Filter Text...',... Default configuration options for each menu item Defaults to:
    menuItemCfgs : {
        emptyText: 'Enter Filter Text...',
        selectOnFocus: true,
        width: 125
    }
| NumericFilter
| menuItemCfgs : Object Default configuration options for each menu item Defaults to: menuItemCfgs : { emptyText: 'Enter Filter Text...',... Default configuration options for each menu item Defaults to:
    menuItemCfgs : {
        emptyText: 'Enter Filter Text...',
        selectOnFocus: true,
        width: 125
    }
| NumericFilter
| menuItems : Array The items to be shown in this menu. Items are added to the menu according to their position within this array. Defau... The items to be shown in this menu. Items are added to the menu according to their position within this array. Defaults to:
    menuItems : ['lt','gt','-','eq']
| NumericFilter
| menuItems : Array The items to be shown in this menu. Items are added to the menu according to their position within this array. Defau... The items to be shown in this menu. Items are added to the menu according to their position within this array. Defaults to:
    menuItems : ['lt','gt','-','eq']
| NumericFilter
| updateBuffer : Number Number of milliseconds to wait after user interaction to fire an update. Only supported by filters: 'list', 'numeric... Number of milliseconds to wait after user interaction to fire an update. Only supported by filters: 'list', 'numeric', and 'string'. Defaults to 500. | Filter

## Public Properties

Property | Defined By
--- | ---
| active : Boolean True if this filter is active. Use setActive() to alter after configuration. | Filter
| getSerialArgs : Object Template method to be implemented by all subclasses that is to get and return serialized filter data for transmission... Template method to be implemented by all subclasses that is to get and return serialized filter data for transmission to the server. Defaults to Ext.emptyFn. | Filter
| init : Object Template method to be implemented by all subclasses that is to initialize the filter and install required menu items.... Template method to be implemented by all subclasses that is to initialize the filter and install required menu items. Defaults to Ext.emptyFn. | Filter
| menu : Ext.menu.Menu The filter configuration menu that will be installed into the filter submenu of a column menu. | Filter

## Public Methods

Method | Defined By
--- | ---
| destroy() : void Destroys this filter by purging any event listeners, and removing any menus. Destroys this filter by purging any event listeners, and removing any menus. Parameters: None. Returns: void | Filter
| getValue() : Object Template method to be implemented by all subclasses that is to get and return the value of the filter. Defaults to Ex... Template method to be implemented by all subclasses that is to get and return the value of the filter. Defaults to Ext.emptyFn. Parameters: None. Returns: `Object` The 'serialized' form of this filter | Filter
| isActivatable() : Boolean Template method to be implemented by all subclasses that is to return true if the filter has enough configuration inf... Template method to be implemented by all subclasses that is to return `true` if the filter has enough configuration information to be activated. Defaults to `return true`. Parameters: None. Returns: `Boolean` | Filter
| serialize() : Object/Array Returns the serialized filter data for transmission to the server and fires the 'serialize' event. Returns the serialized filter data for transmission to the server and fires the 'serialize' event. Parameters: None. Returns: `Object/Array` An object or collection of objects containing key value pairs representing the current configuration of the filter. | Filter
| setActive( `Boolean active`, `Boolean suppressEvent` ) : void Sets the status of the filter and fires the appropriate events. Sets the status of the filter and fires the appropriate events. Parameters: `active` : Boolean The new filter state. `suppressEvent` : Boolean True to prevent events from being fired. Returns: void | Filter
| setValue( `Object data` ) : void Template method to be implemented by all subclasses that is to set the value of the filter and fire the 'update' even... Template method to be implemented by all subclasses that is to set the value of the filter and fire the 'update' event. Defaults to Ext.emptyFn. Parameters: `data` : Object The value to set the filter Returns: void | Filter
| validateRecord( `Ext.data.Record record` ) : Boolean Template method that is to validate the provided Ext.data.Record against the filters configuration. Template method that is to validate the provided Ext.data.Record against the filters configuration. Parameters: `record` : Ext.data.Record The record to validate Returns: `Boolean` true if the record is valid within the bounds of the filter, false otherwise. | NumericFilter

## Public Events

Event | Defined By
--- | ---
| activate : ( `Ext.ux.grid.filter.Filter this` ) Fires when an inactive filter becomes active Fires when an inactive filter becomes active Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter | Filter
| deactivate : ( `Ext.ux.grid.filter.Filter this` ) Fires when an active filter becomes inactive Fires when an active filter becomes inactive Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter | Filter
| serialize : ( `Array/Object data`, `Ext.ux.grid.filter.Filter filter` ) Fires after the serialization process. Use this to attach additional parameters to serialization data before it is en... Fires after the serialization process. Use this to attach additional parameters to serialization data before it is encoded and sent to the server. Listeners will be called with the following arguments: `data` : Array/Object A map or collection of maps representing the current filter configuration. `filter` : Ext.ux.grid.filter.Filter The filter being serialized. | Filter
| update : ( `Ext.ux.grid.filter.Filter this` ) Fires when a filter configuration has changed Fires when a filter configuration has changed Listeners will be called with the following arguments: `this` : Ext.ux.grid.filter.Filter The filter object. | Filter